/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* librvngabw
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2014 osnola
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

#ifndef __FILTERINTERNAL_HXX__
#define __FILTERINTERNAL_HXX__

#include <string.h> // for strcmp

#include <vector>

#include <librevenge/librevenge.h>

#if defined(_MSC_VER) || defined(__DJGPP__)
typedef unsigned int uint32_t;
#else /* !_MSC_VER && !__DJGPP__*/
#  ifdef HAVE_CONFIG_H
#    include <config.h>
#    ifdef HAVE_STDINT_H
#      include <stdint.h>
#    endif
#    ifdef HAVE_INTTYPES_H
#      include <inttypes.h>
#    endif

#  else
// assume that the headers are there inside LibreOffice build when no HAVE_CONFIG_H is defined
#    include <stdint.h>
#    include <inttypes.h>

#  endif

#endif /* _MSC_VER || __DJGPP__ */

#ifdef DEBUG
#include <stdio.h>
namespace librvngabw
{
void printDebugMsg(const char *format, ...) __attribute__((format(printf, 1, 0)));
}
#define RVNGABW_DEBUG_MSG(M) librvngabw::printDebugMsg M
#else
#define RVNGABW_DEBUG_MSG(M)
#endif

#if defined(SHAREDPTR_TR1)
#include <tr1/memory>
using std::tr1::shared_ptr;
#elif defined(SHAREDPTR_STD)
#include <memory>
using std::shared_ptr;
#else
#include <boost/shared_ptr.hpp>
using boost::shared_ptr;
#endif

#define RVNGABW_N_ELEMENTS(m) sizeof(m)/sizeof(m[0])

namespace librvngabw
{

class DocumentElement;

librevenge::RVNGString doubleToString(const double value);
bool getInchValue(librevenge::RVNGProperty const &prop, double &value);
double getInchValue(librevenge::RVNGProperty const &prop);
/** try to append border properties */
void appendBorderProperties(librevenge::RVNGPropertyList const &borderProp,
                            librevenge::RVNGPropertyList &propPropList,
                            bool toParagraph);

//! adds an unicode character to a string
void appendUnicode(uint32_t val, librevenge::RVNGString &buffer);

} // namespace librvngabw

#endif
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
